@@ -290,9 +290,9 @@ extern "C" {
 	  }
 
 	  //construct covariance matrix
-          #pragma omp parallel 
-	  {
-          #pragma omp for private(ii, k, l, h)
+          // #pragma omp parallel 
+	  // {
+          // #pragma omp for private(ii, k, l, h)
 	  for(jj = 0; jj < n; jj++){
 	    for(ii = jj; ii < n; ii++){	
 	      for(k = 0; k < m; k++){
@@ -305,7 +305,7 @@ extern "C" {
 	      }
 	    }
 	  }
-	  } //parallel for
+	  // } //parallel for
 
 	  //invert C and log det cov
 	  detCand = 0;
@@ -394,9 +394,9 @@ extern "C" {
 	}
 	
 	//construct covariance matrix
-        #pragma omp parallel 
-	{
-        #pragma omp for private(ii, k, l, h)
+        // #pragma omp parallel 
+	// {
+        // #pragma omp for private(ii, k, l, h)
 	  for(jj = 0; jj < n; jj++){
 	    for(ii = jj; ii < n; ii++){	
 	      for(k = 0; k < m; k++){
@@ -409,7 +409,7 @@ extern "C" {
 	      }
 	    }
 	  }
-	} //parallel for
+	// } //parallel for
 	
 	//invert C and log det cov
 	detCand = 0;
