@@ -1,7 +1,4 @@
-#include <iostream>
 #include <string>
-using namespace std;
-
 #include <R.h>
 #include <Rinternals.h>
 #include <R_ext/Linpack.h>
@@ -9,7 +6,6 @@ using namespace std;
 #include <R_ext/BLAS.h>
 #include "util.h"
 
-
 extern "C" {
 
   SEXP spPPLMPredict(SEXP X_r, SEXP Y_r, SEXP n_r, SEXP p_r, SEXP m_r, SEXP Z_r, SEXP q_r,
@@ -65,7 +61,7 @@ extern "C" {
     double *knotsPredD = REAL(knotsPredD_r);
   
     bool nugget = static_cast<bool>(INTEGER(nugget_r)[0]);
-    string covModel = CHAR(STRING_ELT(covModel_r,0));
+    std::string covModel = CHAR(STRING_ELT(covModel_r,0));
     bool modPP = static_cast<bool>(INTEGER(modPP_r)[0]);
     int verbose = INTEGER(verbose_r)[0];
     int nReport = INTEGER(nReport_r)[0];
